=============
Release notes
=============

See the :doc:`version numbers</topics/releases/version_numbers>` page for more
information about the version numbering scheme.

Latest Stable Release
=====================

.. releasestree::
    :maxdepth: 1

    2014.7.0

Previous Releases
=================

.. releasestree::
    :maxdepth: 1
    :glob:

    2014.7.0
    2014.1.*
    0.*

.. seealso:: :doc:`Legacy salt-cloud release docs <../cloud/releases/index>`

.. seealso:: :doc:`Legacy salt-api release docs <saltapi/index>`
